@@ -559,6 +559,7 @@ class GenericLdapDict(DictMixin, object):
         '''
         members = []
 
+        self.getattr(self.MEMBER_ATTRLIST)
         for memberattr in self.MEMBER_ATTRLIST:
             try:
                 members = self[memberattr]
@@ -594,6 +595,7 @@ class GenericLdapDict(DictMixin, object):
         self.memberof = []
 
         if len(self.MEMBEROF_ATTRLIST) > 0:
+            self.getattr(self.MEMBEROF_ATTRLIST)
             for attr in self.MEMBEROF_ATTRLIST:
                 if self.has_key(attr) and self[attr] is not None:
                     for dn in self[attr]:
